@@ -119,6 +119,9 @@ def parse_link(line, d):
         d["peer"] = split_content[3]
     elif len(split_content) >= 2:
         d["mac"] = split_content[1]
+        if "promiscuity" in split_content:
+            d["promiscuity"] = split_content[
+                split_content.index('promiscuity') + 1]
 
 
 def parse_inet(line, d):
