@@ -1,7 +1,7 @@
 import doctest
 
 from insights.parsers import cloud_cfg
-from insights.parsers.tests import test_empty_skip
+from insights.parsers.tests import skip_exception_check
 from insights.tests import context_wrap
 
 
@@ -23,7 +23,7 @@ def test_cloud_cfg():
 
 
 def test_cloud_cfg_empty():
-    assert 'Empty output.' in test_empty_skip(cloud_cfg.CloudCfg)
+    assert 'Empty output.' in skip_exception_check(cloud_cfg.CloudCfg)
 
 
 def test_doc_examples():
