@@ -19,6 +19,7 @@ class Specs(SpecSet):
     aws_instance_type = RegistryPoint()
     awx_manage_check_license = RegistryPoint()
     awx_manage_check_license_data = RegistryPoint(filterable=True)
+    awx_manage_print_settings = RegistryPoint()
     azure_instance_type = RegistryPoint()
     azure_instance_plan = RegistryPoint()
     bios_uuid = RegistryPoint()
@@ -147,6 +148,7 @@ class Specs(SpecSet):
     etc_journald_conf = RegistryPoint()
     etc_machine_id = RegistryPoint()
     etc_udev_40_redhat_rules = RegistryPoint(filterable=True)
+    etc_udev_oracle_asm_rules = RegistryPoint(multi_output=True, filterable=True)
     etcd_conf = RegistryPoint(filterable=True)
     ethernet_interfaces = RegistryPoint()
     ethtool_a = RegistryPoint(multi_output=True)
@@ -171,6 +173,7 @@ class Specs(SpecSet):
     foreman_proxy_log = RegistryPoint(filterable=True)
     foreman_satellite_log = RegistryPoint(filterable=True)
     foreman_ssl_access_ssl_log = RegistryPoint(filterable=True)
+    foreman_ssl_error_ssl_log = RegistryPoint(filterable=True)
     foreman_rake_db_migrate_status = RegistryPoint()
     foreman_tasks_config = RegistryPoint(filterable=True)
     freeipa_healthcheck_log = RegistryPoint()
@@ -366,6 +369,7 @@ class Specs(SpecSet):
     mount = RegistryPoint()
     mounts = RegistryPoint()
     mssql_conf = RegistryPoint()
+    mssql_api_assessment = RegistryPoint()
     multicast_querier = RegistryPoint()
     multipath_conf = RegistryPoint()
     multipath_conf_initramfs = RegistryPoint()
@@ -627,6 +631,7 @@ class Specs(SpecSet):
     sysconfig_mongod = RegistryPoint(multi_output=True)
     sysconfig_network = RegistryPoint()
     sysconfig_ntpd = RegistryPoint()
+    sysconfig_oracleasm = RegistryPoint()
     sysconfig_prelink = RegistryPoint()
     sysconfig_sshd = RegistryPoint()
     sysconfig_virt_who = RegistryPoint()
